jQuery(document).ready(function($) {
	'use strict';

	// Handle template list change for multisite
	if ( edbbData.isMultisite ) {
		$('.edbb-templates-list').on('change', function() {
			var id = $(this).val();
			var siteId = $(this).find('option[value="' + id + '"]').data('site');

			if (siteId !== '' && siteId !== undefined) {
				$(this).parent().find('input[type="hidden"]').val(siteId);
			}
		});
	}

	// Handle condition type change
	$('#edbb-settings-form .condition-type').on('change', function() {
		var $row = $(this).closest('tr');

		if ($(this).val() === 'user_role') {
			$row.find('.user-id').addClass('edbb-hide-select');
			$row.find('.user-role').removeClass('edbb-hide-select');
		} else {
			$row.find('.user-id').removeClass('edbb-hide-select');
			$row.find('.user-role').addClass('edbb-hide-select');
		}
	}).trigger('change');

	// Initialize select2 for existing searchable select elements
	$('#edbb-settings-form tbody tr').not('.edbb-repeater-clone').each(function(index, row) {
		$(this).find('.edbb-searchable-select').select2();
	});

	// Update the names of inputs in the row
	function updateRowNames() {
		$('#edbb-settings-form tbody tr').not('.edbb-repeater-clone').each(function(index, row) {
			$(row).find('.row-number').text(index + 1);
			$(row).find('.template').attr('name', `edbb_dashboards[${index}][template]`);
			$(row).find('.condition-type').attr('name', `edbb_dashboards[${index}][condition_type]`);
			$(row).find('.user-role').attr('name', `edbb_dashboards[${index}][user_role]`);
			$(row).find('.user-id').attr('name', `edbb_dashboards[${index}][user_id]`);
			$(row).find('.edbb-dismissible').attr('name', `edbb_dashboards[${index}][dismissible]`);
		});
	}

	// Add a new row
	function addRow() {
		const newRow = $('#edbb-settings-form tbody tr.edbb-repeater-clone')
			.clone(true)
			.removeClass('edbb-repeater-clone')
			.show();

		// Reset the values in the cloned row
		newRow.find('select').val('').trigger('change');
		newRow.find('input[type="checkbox"]').prop('checked', false);

		// Append the new row to the table body
		$('#edbb-settings-form tbody').append(newRow);

		// Initialize select2 for new searchable select elements
		newRow.find('.edbb-searchable-select').select2();

		updateRowNames();
	}

	// Duplicate a row
	function duplicateRow(row) {
		// Destroy existing Select2 instances on the original row before cloning
		row.find('.edbb-searchable-select').each(function() {
			$(this).select2('destroy');
		});

		// Clone the row
		const newRow = row.clone(true);

		// Reinitialize select2 on the original row
		row.find('.edbb-searchable-select').select2();

		// Append the new row to the table body
		$('#edbb-settings-form tbody').append(newRow);

		// Initialize select2 for new searchable select elements in the new row
		newRow.find('.edbb-searchable-select').select2();

		updateRowNames();
	}

	$(document).on('click', '#edbb-add-row', function() {
		addRow();
	});

	$(document).on('click', '.edbb-remove-row', function() {
		$(this).closest('tr').remove();
		updateRowNames();
	});

	$(document).on('click', '.edbb-duplicate-row', function() {
		duplicateRow($(this).closest('tr'));
	});

	// Initialize sortable for the repeater field
	$('#edbb-settings-form tbody').sortable({
		items: '> tr:not(.edbb-repeater-clone)',
		handle: '> td.edbb-move-row',
		update: function(event, ui) {
			updateRowNames();
		}
	}).disableSelection();

	// Initial call to update row numbers and names
	updateRowNames();
});
