<?php
/**
 * Plugin Name: EasyDash for Bricks
 * Plugin URI: https://wpbricksaddons.com/
 * Description: Replaces the default WordPress dashboard welcome panel with a Bricks template.
 * Version: 1.0.1
 * Author: BloomPixel
 * Author URI: https://www.bloompixel.com
 * Copyright: (c) 2025 BloomPixel
 * License: GNU General Public License v3.0
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: easydash-bricks
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'EDBB_VER', '1.0.1' );
define( 'EDBB_DIR', plugin_dir_path( __FILE__ ) );
define( 'EDBB_URL', plugins_url( '/', __FILE__ ) );
define( 'EDBB_PATH', plugin_basename( __FILE__ ) );
define( 'EDBB_FILE', __FILE__ );

final class EDBB_Plugin {

	/**
	 * Holds the current class object.
	 *
	 * @since 1.0.0
	 * @var object
	 */
	public static $instance;

	/**
	 * Primary class constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'bricks_theme_check' ), 11 );
		add_action( 'plugins_loaded', array( $this, 'loader' ) );
	}

	/**
	 * Initializes the plugin.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function loader() {
		require_once EDBB_DIR . 'classes/class-easydash-admin.php';

		$edbb_admin = EDBB_Plugin\Admin::get_instance();
	}

	/**
	 * Check if Bricks is installed and activated.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function bricks_theme_check() {
		if ( ! defined( 'BRICKS_VERSION' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_missing_main_plugin' ) );
			return;
		}
	}

	/**
	 * Admin Notice
	 *
	 * Warning when site doesn't have Bricks installed or activated.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function admin_notice_missing_main_plugin() {
		if ( ! is_admin() || ! is_user_logged_in() || ! current_user_can( 'update_core' ) ) {
			return;
		}

		$message = sprintf(
			/* translators: 1: EasyDash for Bricks, 2: Bricks */
			esc_html__( '%1$s requires %2$s to be installed and activated.', 'easydash-bricks' ),
			'<strong>' . esc_html__( 'EasyDash for Bricks', 'easydash-bricks' ) . '</strong>',
			'<strong>' . esc_html__( 'Bricks', 'easydash-bricks' ) . '</strong>'
		);

		$html = sprintf( '<div class="notice notice-warning">%s</div>', wpautop( $message ) );

		echo wp_kses_post( $html );
	}

	/**
	 * Get the instance of the class.
	 *
	 * @since 1.0.0
	 * @return object
	 */
	public static function get_instance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof EDBB_Plugin ) ) {
			self::$instance = new EDBB_Plugin();
		}

		return self::$instance;
	}
}

// Initialize the class.
$edbb_plugin = EDBB_Plugin::get_instance();