<?php
/**
 * Admin Settings Page Template
 *
 * @package EasyDashBricks
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
?>
<div class="wrap">
	<div class="edbb-settings-header">
		<h1 class="title"><?php echo esc_html( $title ); ?></h1>
	</div>

	<div class="edbb-settings-wrap">
		<?php if ( is_multisite() && get_current_blog_id() !== 1 ) : ?>
			<div class="notice notice-warning edbb-subsite-notice">
				<p><?php esc_html_e( 'Please note, changing the template in subsite will override the main settings.', 'easydash-bricks' ); ?></p>
			</div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php
			settings_fields( 'edbb_options_group' );
			do_settings_sections( 'edbb_options_group' );
			?>
			<table class="widefat fixed" id="edbb-settings-form">
				<thead>
					<tr>
						<th style="width: 20px"></th>
						<th><strong><?php esc_html_e( 'Select Template', 'easydash-bricks' ); ?></strong></th>
						<th><strong><?php esc_html_e( 'Type', 'easydash-bricks' ); ?></strong></th>
						<th><strong><?php esc_html_e( 'User / Role', 'easydash-bricks' ); ?></strong></th>
						<th><strong><?php esc_html_e( 'Is Dismissible?', 'easydash-bricks' ); ?></strong></th>
						<th><strong><?php esc_html_e( 'Actions', 'easydash-bricks' ); ?></strong></th>
					</tr>
				</thead>
				<tbody>
					<?php
					$edbb_dashboards = get_option( 'edbb_dashboards', array() );

					if ( ! empty( $edbb_dashboards ) ) :
						$row_count = 0;
						foreach ( $edbb_dashboards as $index => $row ) :
							$row_number = $row_count + 1;
							?>
							<tr class="<?php echo ( $row_count % 2 === 0 ) ? 'alternate' : ''; ?>">
								<td style="width: 20px" class="edbb-move-row" title="<?php esc_attr_e( 'Drag to reorder', 'easydash-bricks' ); ?>">
									<span class="row-number"><?php echo esc_html( $row_number ); ?></span>
								</td>
								<td>
									<select name="edbb_dashboards[<?php echo esc_attr( $index ); ?>][template]" class="template edbb-searchable-select">
										<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
										<?php foreach ( $templates as $id => $template ) : ?>
											<?php $selected = isset( $row['template'] ) ? $row['template'] : ''; ?>
											<option value="<?php echo esc_attr( $id ); ?>" <?php selected( $selected, $id ); ?> data-site="<?php echo esc_attr( $template['site'] ?? '' ); ?>">
												<?php echo esc_html( $template['title'] ); ?>
											</option>
										<?php endforeach; ?>
									</select>
									<?php if ( is_multisite() ) : ?>
										<input type="hidden" name="edbb_dashboards[<?php echo esc_attr( $index ); ?>][site]" value="<?php echo esc_attr( $settings[ $index ]['site'] ?? '' ); ?>" />
									<?php endif; ?>
								</td>
								<td>
									<select name="edbb_dashboards[<?php echo esc_attr( $index ); ?>][condition_type]" class="condition-type">
										<?php $selected = isset( $row['condition_type'] ) ? $row['condition_type'] : ''; ?>
										<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
										<option value="user_role" <?php selected( $selected, 'user_role' ); ?>><?php esc_html_e( 'User Role', 'easydash-bricks' ); ?></option>
										<option value="user" <?php selected( $selected, 'user' ); ?>><?php esc_html_e( 'User', 'easydash-bricks' ); ?></option>
									</select>
								</td>
								<td class="edbb-user-role-col">
									<select name="edbb_dashboards[<?php echo esc_attr( $index ); ?>][user_role]" class="user-role edbb-searchable-select">
										<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
										<?php foreach ( $roles as $role => $role_title ) : ?>
											<?php $selected = isset( $row['user_role'] ) ? $row['user_role'] : ''; ?>
											<option value="<?php echo esc_attr( $role ); ?>" <?php selected( $selected, $role ); ?>><?php echo esc_html( $role_title ); ?></option>
										<?php endforeach; ?>
									</select>
									<select name="edbb_dashboards[<?php echo esc_attr( $index ); ?>][user_id]" class="user-id edbb-searchable-select">
										<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
										<?php foreach ( $users as $user_id => $user_name ) : ?>
											<?php $selected = isset( $row['user_id'] ) ? $row['user_id'] : ''; ?>
											<option value="<?php echo esc_attr( $user_id ); ?>" <?php selected( $selected, $user_id ); ?>><?php echo esc_html( $user_name ); ?></option>
										<?php endforeach; ?>
									</select>
								</td>
								<td>
									<label class="edbb-admin-field-toggle">
										<input type="checkbox" name="edbb_dashboards[<?php echo esc_attr( $index ); ?>][dismissible]" value="1" <?php checked( isset( $settings[ $index ]['dismissible'] ) && $settings[ $index ]['dismissible'] == '1' ); ?> class="edbb-dismissible" />
										<span class="edbb-admin-field-toggle-slider" aria-hidden="true"></span>
									</label>
								</td>
								<td>
									<button type="button" class="button button-secondary edbb-duplicate-row" title="<?php esc_attr_e( 'Duplicate row', 'easydash-bricks' ); ?>">
										<span class="dashicons dashicons-admin-page"></span>
									</button>
									<button type="button" class="button button-secondary edbb-remove-row" title="<?php esc_attr_e( 'Remove row', 'easydash-bricks' ); ?>">
										<span class="dashicons dashicons-trash"></span>
									</button>
								</td>
							</tr>
							<?php
							$row_count++;
						endforeach;
					endif;
					?>
					<tr class="edbb-repeater-clone">
						<td style="width: 20px" class="edbb-move-row" title="<?php esc_attr_e( 'Drag to reorder', 'easydash-bricks' ); ?>">
							<span class="row-number"></span>
						</td>
						<td>
							<select name="edbb_dashboards_clone_template" class="template edbb-searchable-select">
								<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
								<?php foreach ( $templates as $id => $template ) : ?>
									<option value="<?php echo esc_attr( $id ); ?>" data-site="<?php echo esc_attr( $template['site'] ?? '' ); ?>">
										<?php echo esc_html( $template['title'] ); ?>
									</option>
								<?php endforeach; ?>
							</select>
						</td>
						<td>
							<select name="edbb_dashboards_clone_condition_type" class="condition-type">
								<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
								<option value="user_role"><?php esc_html_e( 'User Role', 'easydash-bricks' ); ?></option>
								<option value="user"><?php esc_html_e( 'User', 'easydash-bricks' ); ?></option>
							</select>
						</td>
						<td class="edbb-user-role-col">
							<select name="edbb_dashboards_clone_user_role" class="user-role edbb-searchable-select">
								<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
								<?php foreach ( $roles as $role => $role_title ) : ?>
									<option value="<?php echo esc_attr( $role ); ?>"><?php echo esc_html( $role_title ); ?></option>
								<?php endforeach; ?>
							</select>
							<select name="edbb_dashboards_clone_user_id" class="user-id edbb-searchable-select">
								<option value=""><?php esc_html_e( '-- Select --', 'easydash-bricks' ); ?></option>
								<?php foreach ( $users as $user_id => $user_name ) : ?>
									<option value="<?php echo esc_attr( $user_id ); ?>"><?php echo esc_html( $user_name ); ?></option>
								<?php endforeach; ?>
							</select>
						</td>
						<td>
							<label class="edbb-admin-field-toggle">
								<input type="checkbox" name="edbb_dashboards_clone_dismissible" value="1" class="edbb-dismissible" />
								<span class="edbb-admin-field-toggle-slider" aria-hidden="true"></span>
							</label>
						</td>
						<td>
							<button type="button" class="button button-secondary edbb-remove-row">
								<span class="dashicons dashicons-trash" title="<?php esc_attr_e( 'Remove row', 'easydash-bricks' ); ?>"></span>
							</button>
							<button type="button" class="button button-secondary edbb-duplicate-row">
								<span class="dashicons dashicons-admin-page" title="<?php esc_attr_e( 'Duplicate row', 'easydash-bricks' ); ?>"></span>
							</button>
						</td>
					</tr>
				</tbody>
			</table>

			<?php if ( is_multisite() && get_current_blog_id() === 1 ) : ?>
				<p>
					<label>
						<input type="checkbox" value="1" name="edbb_hide_from_subsites" <?php checked( get_option( 'edbb_hide_from_subsites' ) ); ?> />
						<?php esc_html_e( 'Hide settings from network subsites', 'easydash-bricks' ); ?>
					</label>
				</p>
			<?php endif; ?>

			<div class="edbb-form-actions">
				<p>
					<button type="button" class="button button-secondary" id="edbb-add-row"><?php esc_html_e( 'Add Row', 'easydash-bricks' ); ?></button>
				</p>
				<?php submit_button(); ?>
			</div>
		</form>
	</div>
</div>
